@@ -141,8 +141,6 @@ gint deltaU, deltaN, deltaIO, deltaI;
 static gint sshotn = 0;
 static PluginInfo *info = NULL;
 static gboolean im_inactive = FALSE;
-static GdkDrawable *root_window;
-static int width, height;
 #define MAX_READ_CHARS 128
 static char read_buffer[MAX_READ_CHARS];
 #define MAX_SSHOT_NAME_LEN 64
@@ -358,6 +356,8 @@ setup_filename (gchar *suffix)
 static void
 make_screenshot(void)
 {
+	int width, height;
+	GdkDrawable *root_window;
 	GdkPixbuf *pixbuf;
 	gboolean ret;
 	GError *error = NULL;
@@ -366,6 +366,8 @@ make_screenshot(void)
 	setup_filename ("png");
 
 
+	root_window = gdk_get_default_root_window ();
+	gdk_drawable_get_size (root_window, &width, &height);
 	pixbuf = gdk_pixbuf_get_from_drawable (NULL,
                                            root_window,
                                            gdk_drawable_get_colormap (root_window),
@@ -977,8 +979,6 @@ load_initialize(HildonStatusBarItem *item,
     info->timeout_id = gtk_timeout_add(1000, check_load_cpu, info);
 
     /* Screenshot stuff too */
-    root_window = gdk_get_default_root_window ();
-    gdk_drawable_get_size (root_window, &width, &height);
     sshotfilename = g_strdup(SSHOT_DEFAULT_NAME);
     info->last_cpu_level = 0;
     info->last_mem_level = 0;
